gnucash unstable: Replace ambiguous 'scm' with 'vcs' in macro name

Geert Janssens gjanssens at code.gnucash.org
Thu Oct 5 16:47:59 EDT 2017


Updated	 via  https://github.com/Gnucash/gnucash/commit/9472e934 (commit)
	from  https://github.com/Gnucash/gnucash/commit/29b862ad (commit)



commit 9472e9347fd6d56ccefec3da5f4614102b8d044f
Author: Geert Janssens <geert at kobaltwit.be>
Date:   Thu Oct 5 22:47:11 2017 +0200

    Replace ambiguous 'scm' with 'vcs' in macro name
    
    Pointed out by Frank.

diff --git a/doc/CMakeLists.txt b/doc/CMakeLists.txt
index d93f996..5d8548e 100644
--- a/doc/CMakeLists.txt
+++ b/doc/CMakeLists.txt
@@ -66,7 +66,7 @@ SET(VCS_INFO_FILE ${VCS_INFO_BASE_DIR}/libgnucash/core-utils/gnc-vcs-info.h)
 # have to end up in the file being written...
 # eg \\\" will become \", \\\\1 will become \\1 (which cmake will then interpret as \1)
 FILE(WRITE ${CMAKE_CURRENT_BINARY_DIR}/manpage.cmake
-"FILE(STRINGS \${VCS_INFO_FILE} ym_line REGEX \"GNUCASH_SCM_REV_Y_M\")
+"FILE(STRINGS \${VCS_INFO_FILE} ym_line REGEX \"GNC_VCS_REV_Y_M\")
 STRING(REGEX REPLACE \"^.* \\\"(.*)\\\"\" \"\\\\1\" DATE \${ym_line})
 CONFIGURE_FILE(\${SRC} \${DST} )
 FILE(COPY gnucash.1
diff --git a/doc/Makefile.am b/doc/Makefile.am
index 0bca450..2959220 100644
--- a/doc/Makefile.am
+++ b/doc/Makefile.am
@@ -41,17 +41,17 @@ EXTRA_DIST = \
 gnucash.1: gnucash.1.in Makefile
 	rm -f $@.tmp
 if BUILDING_FROM_VCS
-	GNUCASH_SCM_REV_Y_M=`perl -ne 'print if $$_=~s/.*GNUCASH_SCM_REV_Y_M "(.*)"/$$1/' ${top_builddir}/libgnucash/core-utils/gnc-vcs-info.h` ; \
+	GNC_VCS_REV_Y_M=`perl -ne 'print if $$_=~s/.*GNC_VCS_REV_Y_M "(.*)"/$$1/' ${top_builddir}/libgnucash/core-utils/gnc-vcs-info.h` ; \
 	${SED} < $< > $@.tmp \
             -e 's:$${VERSION}:${VERSION}:g' \
-            -e 's:$${DATE}:'$${GNUCASH_SCM_REV_Y_M}':g'
+            -e 's:$${DATE}:'$${GNC_VCS_REV_Y_M}':g'
 	chmod +x $@.tmp
 	mv $@.tmp $@
 else
-	GNUCASH_SCM_REV_Y_M=`perl -ne 'print if $$_=~s/.*GNUCASH_SCM_REV_Y_M "(.*)"/$$1/' ${top_srcdir}/libgnucash/core-utils/gnc-vcs-info.h` ; \
+	GNC_VCS_REV_Y_M=`perl -ne 'print if $$_=~s/.*GNC_VCS_REV_Y_M "(.*)"/$$1/' ${top_srcdir}/libgnucash/core-utils/gnc-vcs-info.h` ; \
 	${SED} < $< > $@.tmp \
 	-e 's:$${VERSION}:${VERSION}:g' \
-	-e 's:$${DATE}:'$${GNUCASH_SCM_REV_Y_M}':g'
+	-e 's:$${DATE}:'$${GNC_VCS_REV_Y_M}':g'
 	chmod +x $@.tmp
 	mv $@.tmp $@
 endif
diff --git a/gnucash/gnome-utils/gnc-main-window.c b/gnucash/gnome-utils/gnc-main-window.c
index 33a3c33..9f7dba6 100644
--- a/gnucash/gnome-utils/gnc-main-window.c
+++ b/gnucash/gnome-utils/gnc-main-window.c
@@ -4464,7 +4464,7 @@ gnc_main_window_cmd_help_about (GtkAction *action, GncMainWindow *window)
 	const gchar *fixed_message = _("The GnuCash personal finance manager. "
                                    "The GNU way to manage your money!");
 	gchar *copyright = g_strdup_printf(_("© 1997-%s Contributors"),
-                                           GNUCASH_SCM_REV_YEAR);
+                                           GNC_VCS_REV_YEAR);
 	gchar **authors = get_file_strsplit("AUTHORS");
 	gchar **documenters = get_file_strsplit("DOCUMENTERS");
 	gchar *license = get_file("LICENSE");
@@ -4477,22 +4477,22 @@ gnc_main_window_cmd_help_about (GtkAction *action, GncMainWindow *window)
                                                     NULL);
 
 
-#ifdef GNUCASH_SCM
+#ifdef GNC_VCS
     /* Development version */
     /* Translators: 1st %s is a fixed message, which is translated independently;
                     2nd %s is the scm type (svn/svk/git/bzr);
                     3rd %s is the scm revision number;
                     4th %s is the build date */
 	message = g_strdup_printf(_("%s\nThis copy was built from %s rev %s (commit date %s)."),
-                                  fixed_message, GNUCASH_SCM, GNUCASH_SCM_REV,
-                                  GNUCASH_SCM_REV_DATE);
+                                  fixed_message, GNC_VCS, GNC_VCS_REV,
+                                  GNC_VCS_REV_DATE);
 #else
     /* Translators: 1st %s is a fixed message, which is translated independently;
                     2nd %s is the scm (svn/svk/git/bzr) revision number;
                     3rd %s is the build date */
 	message = g_strdup_printf(_("%s\nThis copy was built from rev %s (commit date %s)."),
-                                  fixed_message, GNUCASH_SCM_REV,
-                                  GNUCASH_SCM_REV_DATE);
+                                  fixed_message, GNC_VCS_REV,
+                                  GNC_VCS_REV_DATE);
 #endif
 	priv->about_dialog = gtk_about_dialog_new ();
 	g_object_set (priv->about_dialog,
diff --git a/gnucash/gnome-utils/gnc-splash.c b/gnucash/gnome-utils/gnc-splash.c
index bd7c795..2cb6828 100644
--- a/gnucash/gnome-utils/gnc-splash.c
+++ b/gnucash/gnome-utils/gnc-splash.c
@@ -93,22 +93,22 @@ gnc_show_splash_screen (void)
     gtk_box_set_homogeneous (GTK_BOX (vbox), FALSE);
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
     gtk_box_set_homogeneous (GTK_BOX (hbox), FALSE);
-#ifdef GNUCASH_SCM
+#ifdef GNC_VCS
     /* Development version */
     /* Translators: 1st %s is the GnuCash version (eg 2.4.11);
                     2nd %s is the scm type (svn/svk/git/bzr);
                     3rd %s is the scm revision number;
                     4th %s is the build date */
     ver_string = g_strdup_printf(_("Version: GnuCash-%s %s (rev %s, commit date %s)"),
-                                 VERSION, GNUCASH_SCM, GNUCASH_SCM_REV,
-                                 GNUCASH_SCM_REV_DATE);
+                                 VERSION, GNC_VCS, GNC_VCS_REV,
+                                 GNC_VCS_REV_DATE);
 #else
     /* Dist Tarball */
     /* Translators: 1st %s is the GnuCash version (eg 2.4.11);
                     2nd %s is the scm (svn/svk/git/bzr) revision number;
                     3rd %s is the build date */
     ver_string = g_strdup_printf(_("Version: GnuCash-%s (rev %s, commit date %s)"),
-                                 VERSION, GNUCASH_SCM_REV, GNUCASH_SCM_REV_DATE);
+                                 VERSION, GNC_VCS_REV, GNC_VCS_REV_DATE);
 #endif
 
     version = gtk_label_new(NULL);
diff --git a/libgnucash/core-utils/CMakeLists.txt b/libgnucash/core-utils/CMakeLists.txt
index 59dd00c..d667b9e 100644
--- a/libgnucash/core-utils/CMakeLists.txt
+++ b/libgnucash/core-utils/CMakeLists.txt
@@ -56,7 +56,7 @@ SET (GNC_VERSION_H_IN
 #ifndef GNC_VERSION_H
 #define GNC_VERSION_H
 
-#define GNUCASH_SCM \"git\"
+#define GNC_VCS \"git\"
 #include \"gnc-vcs-info.h\"
 #endif
 ")
@@ -71,10 +71,10 @@ FILE (WRITE ${CMAKE_CURRENT_BINARY_DIR}/gnc-version.h ${GNC_VERSION_H_CONTENT})
 IF (BUILDING_FROM_VCS)
 FILE(WRITE ${CMAKE_CURRENT_BINARY_DIR}/gnc-vcs-info.h.in
 "/* Autogenerated. Do not change. */
-#define GNUCASH_SCM_REV \"@GNUCASH_SCM_REV@\"
-#define GNUCASH_SCM_REV_DATE \"@GNUCASH_SCM_REV_DATE@\"
-#define GNUCASH_SCM_REV_YEAR \"@GNUCASH_SCM_REV_YEAR@\"
-#define GNUCASH_SCM_REV_Y_M \"@GNUCASH_SCM_REV_Y_M@\"
+#define GNC_VCS_REV \"@GNC_VCS_REV@\"
+#define GNC_VCS_REV_DATE \"@GNC_VCS_REV_DATE@\"
+#define GNC_VCS_REV_YEAR \"@GNC_VCS_REV_YEAR@\"
+#define GNC_VCS_REV_Y_M \"@GNC_VCS_REV_Y_M@\"
 ")
 
 SET(SCM_REV_COMMAND "${CMAKE_SOURCE_DIR}/util/gnc-vcs-info -r")
@@ -82,16 +82,16 @@ SET(SCM_REV_DATE_COMMAND "${CMAKE_SOURCE_DIR}/util/gnc-vcs-info -d")
 FILE(WRITE ${CMAKE_CURRENT_BINARY_DIR}/version.cmake
   "EXECUTE_PROCESS(
     COMMAND ${SHELL} ${SCM_REV_COMMAND} ${CMAKE_SOURCE_DIR}
-    OUTPUT_VARIABLE GNUCASH_SCM_REV
+    OUTPUT_VARIABLE GNC_VCS_REV
     OUTPUT_STRIP_TRAILING_WHITESPACE
   )
   EXECUTE_PROCESS(
     COMMAND ${SHELL} ${SCM_REV_DATE_COMMAND} ${CMAKE_SOURCE_DIR}
-    OUTPUT_VARIABLE GNUCASH_SCM_REV_DATE
+    OUTPUT_VARIABLE GNC_VCS_REV_DATE
     OUTPUT_STRIP_TRAILING_WHITESPACE
   )
-  STRING(SUBSTRING \${GNUCASH_SCM_REV_DATE} 0 4 GNUCASH_SCM_REV_YEAR)
-  STRING(SUBSTRING \${GNUCASH_SCM_REV_DATE} 0 7 GNUCASH_SCM_REV_Y_M)
+  STRING(SUBSTRING \${GNC_VCS_REV_DATE} 0 4 GNC_VCS_REV_YEAR)
+  STRING(SUBSTRING \${GNC_VCS_REV_DATE} 0 7 GNC_VCS_REV_Y_M)
   CONFIGURE_FILE(\${SRC} \${DST} @ONLY)
 ")
 
diff --git a/libgnucash/core-utils/Makefile.am b/libgnucash/core-utils/Makefile.am
index 05f5178..fdd2ebe 100644
--- a/libgnucash/core-utils/Makefile.am
+++ b/libgnucash/core-utils/Makefile.am
@@ -166,7 +166,7 @@ _gnc-version.h: gnc-vcs-info.h Makefile
 	@echo ""                                     >> _gnc-version.h
 	@scm_info=`${top_srcdir}/util/gnc-vcs-info -t ${top_srcdir}` ; \
 	if [ $$? = 0 ] ; then \
-		echo "#define GNUCASH_SCM \"$$scm_info\"" >> _gnc-version.h ; \
+		echo "#define GNC_VCS \"$$scm_info\"" >> _gnc-version.h ; \
 	fi
 	@echo "#include \"gnc-vcs-info.h\""          >> _gnc-version.h
 	@echo "#endif"                               >> _gnc-version.h
@@ -193,9 +193,9 @@ _gnc-vcs-info.h: Makefile
 			exit 1 ; \
 		fi ; \
 		echo "/* Autogenerated. Do not change. */"    > _gnc-vcs-info.h ; \
-		echo "#define GNUCASH_SCM_REV \"$$scm_info\"" >> _gnc-vcs-info.h ; \
-		echo "#define GNUCASH_SCM_REV_DATE \"$$scm_date\"" >> _gnc-vcs-info.h ; \
-		echo "#define GNUCASH_SCM_REV_YEAR \"$${scm_date%%-*}\"" >> _gnc-vcs-info.h ; \
-		echo "#define GNUCASH_SCM_REV_Y_M \"$${scm_date%-*}\"" >> _gnc-vcs-info.h ; \
+		echo "#define GNC_VCS_REV \"$$scm_info\"" >> _gnc-vcs-info.h ; \
+		echo "#define GNC_VCS_REV_DATE \"$$scm_date\"" >> _gnc-vcs-info.h ; \
+		echo "#define GNC_VCS_REV_YEAR \"$${scm_date%%-*}\"" >> _gnc-vcs-info.h ; \
+		echo "#define GNC_VCS_REV_Y_M \"$${scm_date%-*}\"" >> _gnc-vcs-info.h ; \
 	fi
 endif



Summary of changes:
 doc/CMakeLists.txt                    |  2 +-
 doc/Makefile.am                       |  8 ++++----
 gnucash/gnome-utils/gnc-main-window.c | 12 ++++++------
 gnucash/gnome-utils/gnc-splash.c      |  8 ++++----
 gnucash/gnucash-bin.c                 | 12 ++++++------
 libgnucash/core-utils/CMakeLists.txt  | 18 +++++++++---------
 libgnucash/core-utils/Makefile.am     | 10 +++++-----
 7 files changed, 35 insertions(+), 35 deletions(-)



More information about the gnucash-changes mailing list
diff --git a/gnucash/gnucash-bin.c b/gnucash/gnucash-bin.c
index 671ab95..d0b26ff 100644
--- a/gnucash/gnucash-bin.c
+++ b/gnucash/gnucash-bin.c
@@ -68,12 +68,12 @@ static QofLogModule log_module = GNC_MOD_GUI;
 #  include <Foundation/Foundation.h>
 #endif
 
 /* GNUCASH_SCM is defined whenever we're building from an svn/svk/git/bzr tree */
 #ifdef GNUCASH_SCM
 static int is_development_version = TRUE;
 #else
 static int is_development_version = FALSE;
-#define GNUCASH_SCM ""
+#define GNC_VCS ""
 #endif
 
 /* Command-line option variables */
@@ -453,8 +453,8 @@ gnc_parse_command_line(int *argc, char ***argv)
                             3rd %s is the scm revision number;
                             4th %s is the build date */
             g_print ( _("%s\nThis copy was built from %s rev %s (commit date %s)."),
-                      fixed_message, GNUCASH_SCM, GNUCASH_SCM_REV,
-                      GNUCASH_SCM_REV_DATE );
+                      fixed_message, GNC_VCS, GNC_VCS_REV,
+                      GNC_VCS_REV_DATE );
         }
         else
         {
@@ -464,7 +464,7 @@ gnc_parse_command_line(int *argc, char ***argv)
                             2nd %s is the scm (svn/svk/git/bzr) revision number;
                             3rd %s is the build date */
             g_print ( _("%s\nThis copy was built from rev %s (commit date %s)."),
-                      fixed_message, GNUCASH_SCM_REV, GNUCASH_SCM_REV_DATE );
+                      fixed_message, GNC_VCS_REV, GNC_VCS_REV_DATE );
         }
         g_print("\n");
         g_free (fixed_message);
@@ -68,12 +68,12 @@ static QofLogModule log_module = GNC_MOD_GUI;
 #endif
 
-/* GNUCASH_SCM is defined whenever we're building from an svn/svk/git/bzr tree */
-#ifdef GNUCASH_SCM
+/* GNC_VCS is defined whenever we're building from an svn/svk/git/bzr tree */
+#ifdef GNC_VCS
 static int is_development_version = TRUE;
 #else